from typing import List

from pydantic import BaseModel
from telegram_pydantic.models.poll.poll_option import PollOption
from telegram_pydantic.models.message_entity import MessageEntity


class Poll(BaseModel):
    id: str
    question: str
    options: List[PollOption]
    total_voter_count: str
    is_closed: bool
    is_anonymous: bool
    type: str
    allows_multiple_answers: bool
    correct_option_id: int = None
    explanation: str = None
    explanation_entities: List[MessageEntity] = None
    open_period: int = None
    close_date: int = None



from typing import List

from pydantic import BaseModel
from telegram_pydantic.models.photo_size import PhotoSize
from telegram_pydantic.models.message_entity import MessageEntity
from telegram_pydantic.models.media.animation import Animation


class Game(BaseModel):
    title: str
    description: str
    photo: List[PhotoSize]
    text: str
    text_entities: List[MessageEntity]
    animation: Animation



from pydantic import Field, BaseModel
from telegram_pydantic.models.user import User
from telegram_pydantic.models.location import Location


class ChosenInlineResult(BaseModel):
    result_id: str
    result_from: User = Field(alias="from")
    location: Location = None
    inline_message_id: str = None
    query: str



from pydantic import BaseModel
from telegram_pydantic.models.message import Message
from telegram_pydantic.models.poll.poll import Poll
from telegram_pydantic.models.callback_query import CallbackQuery
from telegram_pydantic.models.poll.poll_answer import PollAnswer
from telegram_pydantic.models.payments.shipping_query import ShippingQuery
from telegram_pydantic.models.chat.chat_member_updated import ChatMemberUpdated
from telegram_pydantic.models.inline_mode.inline_query import InlineQuery
from telegram_pydantic.models.payments.pre_checkout_query import PreCheckoutQuery
from telegram_pydantic.models.inline_mode.chosen_inline_result import ChosenInlineResult


class MessageUpdate(BaseModel):
    update_id: int
    message: Message = None
    edited_message: Message = None
    channel_post: Message = None
    edited_channel_post: Message = None
    inline_query: InlineQuery = None
    chosen_inline_result: ChosenInlineResult = None
    callback_query: CallbackQuery = None
    shipping_query: ShippingQuery = None
    pre_checkout_query: PreCheckoutQuery = None
    poll: Poll = None
    poll_answer: PollAnswer = None
    my_chat_member: ChatMemberUpdated = None
    chat_member: ChatMemberUpdated = None



from pydantic import BaseModel


class ChatPermissions(BaseModel):
    can_send_messages: bool = None
    can_send_media_messages: bool = None
    can_send_polls: bool = None
    can_send_other_messages: bool = None
    can_add_web_page_previews: bool = None
    can_change_info: bool = None
    can_invite_users: bool = None
    can_pin_messages: bool = None



from typing import Any, Optional

from telegram_pydantic.models.input_media.input_media import InputMedia


class InputMediaAudio(InputMedia):
    thumb: Optional[Any]
    duration: Optional[int]
    performer: Optional[str]
    title: Optional[str]



from pydantic import Field, BaseModel
from telegram_pydantic.models.user import User
from telegram_pydantic.models.payments.shipping_address import ShippingAddress


class ShippingQuery(BaseModel):
    id: str
    query_from: User = Field(alias="from")
    invoice_payload: str
    shipping_address: ShippingAddress



from typing import Any, Optional

from pydantic import BaseModel, Field

from telegram_pydantic.models.message_entity import MessageEntity


class InputMedia(BaseModel):
    media_type: str = Field(alias="type")
    media: Any
    caption: Optional[str]
    parse_mode: Optional[str]
    caption_entities: Optional[MessageEntity]



from telegram_pydantic.models.media.dice import Dice
from telegram_pydantic.models.media.file import File
from telegram_pydantic.models.media.audio import Audio
from telegram_pydantic.models.media.video import Video
from telegram_pydantic.models.media.voice import Voice
from telegram_pydantic.models.media.contact import Contact
from telegram_pydantic.models.media.document import Document
from telegram_pydantic.models.media.animation import Animation
from telegram_pydantic.models.media.video_note import VideoNote

__all__ = ["Dice", "File", "Audio", "Video", "Voice", "Contact", "Document", "Animation", "VideoNote"]



from pydantic import BaseModel
from telegram_pydantic.models.photo_size import PhotoSize


class Document(BaseModel):
    file_id: str
    file_unique_id: str
    thumb: PhotoSize = None
    file_name: str = None
    mime_type: str = None
    file_size: int = None



from pydantic import BaseModel
from telegram_pydantic.models.user import User


class MessageEntity(BaseModel):
    type: str
    offset: int
    length: int
    url: str = None
    user: User = None
    language: str = None



from telegram_pydantic.models.passport.passport_data import PassportData
from telegram_pydantic.models.passport.passport_file import PassportFile
from telegram_pydantic.models.passport.encrypted_credentials import EncryptedCredentials
from telegram_pydantic.models.passport.encypted_passport_element import EncryptedPassportElement

__all__ = ["PassportData", "PassportFile", "EncryptedCredentials", "EncryptedPassportElement"]



from telegram_pydantic.models.keyboard.inline_keyboard_button import InlineKeyboardButton
from telegram_pydantic.models.keyboard.inline_keyboard_markup import InlineKeyboardMarkup

__all__ = ["InlineKeyboardButton", "InlineKeyboardMarkup"]



from __future__ import annotations
from typing import List

from pydantic import Field, BaseModel
from telegram_pydantic.models.user import User
from telegram_pydantic.models.venue import Venue
from telegram_pydantic.models.location import Location
from telegram_pydantic.models.chat.chat import Chat
from telegram_pydantic.models.poll.poll import Poll
from telegram_pydantic.models.games.game import Game
from telegram_pydantic.models.media.dice import Dice
from telegram_pydantic.models.photo_size import PhotoSize
from telegram_pydantic.models.media.audio import Audio
from telegram_pydantic.models.media.video import Video
from telegram_pydantic.models.media.voice import Voice
from telegram_pydantic.models.media.contact import Contact
from telegram_pydantic.models.media.document import Document
from telegram_pydantic.models.message_entity import MessageEntity
from telegram_pydantic.models.media.animation import Animation
from telegram_pydantic.models.media.video_note import VideoNote
from telegram_pydantic.models.payments.invoice import Invoice
from telegram_pydantic.models.stickers.sticker import Sticker
from telegram_pydantic.models.passport.passport_data import PassportData
from telegram_pydantic.models.proximity_alert_triggered import ProximityAlertTriggered
from telegram_pydantic.models.payments.successful_payment import SuccessfulPayment
from telegram_pydantic.models.voice_chat.voice_chat_ended import VoiceChatEnded
from telegram_pydantic.models.voice_chat.voice_chat_started import VoiceChatStarted
from telegram_pydantic.models.keyboard.inline_keyboard_markup import InlineKeyboardMarkup
from telegram_pydantic.models.voice_chat.voice_chat_scheduled import VoiceChatScheduled
from telegram_pydantic.models.message_auto_delete_timer_changed import MessageAutoDeleteTimerChanged
from telegram_pydantic.models.voice_chat.voice_chat_participants_invited import VoiceChatParticipantsInvited


class Message(BaseModel):
    message_id: int
    message_from: User = Field(alias="from", default=None)
    sender_chat: Chat = None
    date: int
    chat: Chat
    forward_from: User = None
    forward_from_chat: Chat = None
    forward_from_message_id: int = None
    forward_signature: str = None
    forward_sender_name: str = None
    forward_date: int = None
    reply_to_message: Message = None
    via_bot: User = None
    edit_date: int = None
    media_group_id: str = None
    author_signature: str = None
    text: str = None
    entities: List[MessageEntity] = None
    animation: Animation = None
    audio: Audio = None
    document: Document = None
    photo: List[PhotoSize] = None
    sticker: Sticker = None
    video: Video = None
    video_note: VideoNote = None
    voice: Voice = None
    caption: str = None
    caption_entities: List[MessageEntity] = None
    contact: Contact = None
    dice: Dice = None
    game: Game = None
    poll: Poll = None
    venue: Venue = None
    location: Location = None
    new_chat_members: List[User] = None
    left_chat_member: User = None
    new_chat_title: str = None
    new_chat_photo: List[PhotoSize] = None
    delete_chat_photo: bool = None
    group_chat_created: bool = None
    supergroup_chat_created: bool = None
    channel_chat_created: bool = None
    message_auto_delete_timer_changed: MessageAutoDeleteTimerChanged = None
    migrate_to_chat_id: int = None
    migrate_from_chat_id: int = None
    pinned_message: Message = None
    invoice: Invoice = None
    successful_payment: SuccessfulPayment = None
    connected_website: str = None
    passport_data: PassportData = None
    proximity_alert_triggered: ProximityAlertTriggered = None
    voice_chat_scheduled: VoiceChatScheduled = None
    voice_chat_started: VoiceChatStarted = None
    voice_chat_ended: VoiceChatEnded = None
    voice_chat_participants_invited: VoiceChatParticipantsInvited = None
    reply_markup: InlineKeyboardMarkup = None


Message.update_forward_refs()



from pydantic import BaseModel
from telegram_pydantic.models.photo_size import PhotoSize
from telegram_pydantic.models.stickers.mask_position import MaskPosition


class Sticker(BaseModel):
    file_id: str
    file_unique_id: str
    width: int
    height: int
    is_animated: bool
    thumb: PhotoSize = None
    emoji: str = None
    set_name: str = None
    mask_position: MaskPosition = None
    file_size: int = None



from typing import Any, Optional

from telegram_pydantic.models.input_media.input_media import InputMedia


class InputMediaVideo(InputMedia):
    thumb: Optional[Any]
    width: Optional[int]
    height: Optional[int]
    duration: Optional[int]
    supports_streaming: Optional[bool]



from telegram_pydantic.models.voice_chat.voice_chat_ended import VoiceChatEnded
from telegram_pydantic.models.voice_chat.voice_chat_started import VoiceChatStarted
from telegram_pydantic.models.voice_chat.voice_chat_scheduled import VoiceChatScheduled
from telegram_pydantic.models.voice_chat.voice_chat_participants_invited import VoiceChatParticipantsInvited

__all__ = ["VoiceChatEnded", "VoiceChatStarted", "VoiceChatScheduled", "VoiceChatParticipantsInvited"]



from telegram_pydantic.models.payments.invoice import Invoice
from telegram_pydantic.models.payments.order_info import OrderInfo
from telegram_pydantic.models.payments.shipping_query import ShippingQuery
from telegram_pydantic.models.payments.shipping_address import ShippingAddress
from telegram_pydantic.models.payments.pre_checkout_query import PreCheckoutQuery
from telegram_pydantic.models.payments.successful_payment import SuccessfulPayment

__all__ = ["Invoice", "OrderInfo", "ShippingQuery", "ShippingAddress", "PreCheckoutQuery", "SuccessfulPayment"]



from pydantic import BaseModel


class Location(BaseModel):
    longitude: float
    latitude: float
    horizontal_accuracy: float = None
    live_period: int = None
    heading: int = None
    proximity_alert_radius: int = None



from pydantic import BaseModel
from telegram_pydantic.models.photo_size import PhotoSize


class Animation(BaseModel):
    file_id: str
    file_unique_id: str
    width: int
    height: int
    duration: int
    thumb: PhotoSize = None
    file_name: str = None
    mime_type: str = None
    file_size: int = None



from telegram_pydantic.models.inline_mode.inline_query import InlineQuery
from telegram_pydantic.models.inline_mode.chosen_inline_result import ChosenInlineResult

__all__ = ["InlineQuery", "ChosenInlineResult"]



from telegram_pydantic.models.input_media.input_media import InputMedia
from telegram_pydantic.models.input_media.input_media_audio import InputMediaAudio
from telegram_pydantic.models.input_media.input_media_video import InputMediaVideo
from telegram_pydantic.models.input_media.input_media_document import InputMediaDocument
from telegram_pydantic.models.input_media.input_media_animation import InputMediaAnimation

__all__ = ["InputMedia", "InputMediaAudio", "InputMediaVideo", "InputMediaDocument", "InputMediaAnimation"]



from typing import List

from pydantic import BaseModel
from telegram_pydantic.models.passport.passport_file import PassportFile


class EncryptedPassportElement(BaseModel):
    type: str
    data: str = None
    phone_number: str = None
    email: str = None
    files: List[PassportFile] = None
    front_side: PassportFile = None
    reverse_side: PassportFile = None
    selfie: PassportFile = None
    translation: List[PassportFile] = None
    hash: str



from pydantic import BaseModel
from telegram_pydantic.models.payments.shipping_address import ShippingAddress


class OrderInfo(BaseModel):
    name: str = None
    phone_number: str = None
    email: str = None
    shipping_address: ShippingAddress = None



from typing import List

from pydantic import BaseModel
from telegram_pydantic.models.photo_size import PhotoSize


class UserProfilePhotos(BaseModel):
    total_count: int
    photos: List[PhotoSize]



from pydantic import Field, BaseModel
from telegram_pydantic.models.user import User
from telegram_pydantic.models.payments.order_info import OrderInfo


class PreCheckoutQuery(BaseModel):
    id: str
    query_from: User = Field(alias="from")
    currency: str
    total_amount: int
    invoice_payload: str
    shipping_option_id: str = None
    order_info: OrderInfo = None



from pydantic import Field, BaseModel
from telegram_pydantic.models.user import User
from telegram_pydantic.models.message import Message


class CallbackQuery(BaseModel):
    id: str
    query_from: User = Field(alias="from")
    message: Message = None
    inline_message_id: str = None
    chat_instance: str = None
    data: str = None
    game_short_name: str = None



from pydantic import BaseModel
from telegram_pydantic.models.login_url import LoginUrl
from telegram_pydantic.models.games.callback_game import CallbackGame


class InlineKeyboardButton(BaseModel):
    text: str
    url: str = None
    login_url: LoginUrl = None
    callback_data: str = None
    switch_inline_query: str = None
    switch_inline_query_current_chat: str = None
    callback_game: CallbackGame = None
    pay: bool = None



from pydantic import BaseModel
from telegram_pydantic.models.payments.order_info import OrderInfo


class SuccessfulPayment(BaseModel):
    currency: str
    total_amount: int
    invoice_payload: str
    shipping_option_id: str = None
    order_info: OrderInfo = None
    telegram_payment_charge_id: str
    provider_payment_charge_id: str



from pydantic import BaseModel
from telegram_pydantic.models.user import User


class ChatInviteLink(BaseModel):
    invite_link: str
    creator: User
    is_primary: bool
    is_revoked: bool
    expire_date: int
    member_limit: int



from pydantic import Field, BaseModel
from telegram_pydantic.models.user import User
from telegram_pydantic.models.chat.chat import Chat
from telegram_pydantic.models.chat.chat_member import ChatMember
from telegram_pydantic.models.chat.chat_invite_link import ChatInviteLink


class ChatMemberUpdated(BaseModel):
    chat: Chat
    update_from: User = Field(alias="from")
    date: int
    old_chat_member: ChatMember
    new_chat_member: ChatMember
    invite_link: ChatInviteLink = None



from pydantic import BaseModel
from telegram_pydantic.models.location import Location


class Venue(BaseModel):
    location: Location
    title: str
    address: str
    foursquare_id: str = None
    foursquare_type: str = None
    google_place_id: str = None
    google_place_type: str = None



from pydantic import Field, BaseModel
from telegram_pydantic.models.user import User
from telegram_pydantic.models.location import Location


class InlineQuery(BaseModel):
    id: str
    query_from: User = Field(alias="from")
    query: str
    offset: str
    chat_type: str = None
    location: Location = None



from typing import List

from pydantic import BaseModel
from telegram_pydantic.models.passport.encrypted_credentials import EncryptedCredentials
from telegram_pydantic.models.passport.encypted_passport_element import EncryptedPassportElement


class PassportData(BaseModel):
    data: List[EncryptedPassportElement]
    credentials: EncryptedCredentials



from typing import List

from pydantic import BaseModel
from telegram_pydantic.models.keyboard.inline_keyboard_button import InlineKeyboardButton


class InlineKeyboardMarkup(BaseModel):
    inline_keyboard: List[InlineKeyboardButton]



from telegram_pydantic.models.chat import *
from telegram_pydantic.models.poll import *
from telegram_pydantic.models.poll import Poll
from telegram_pydantic.models.user import User
from telegram_pydantic.models.games import *
from telegram_pydantic.models.media import *
from telegram_pydantic.models.venue import Venue
from telegram_pydantic.models.message import Message
from telegram_pydantic.models.keyboard import *
from telegram_pydantic.models.location import Location
from telegram_pydantic.models.passport import *
from telegram_pydantic.models.payments import *
from telegram_pydantic.models.stickers import *
from telegram_pydantic.models.login_url import LoginUrl
from telegram_pydantic.models.message_id import MessageId
from telegram_pydantic.models.photo_size import PhotoSize
from telegram_pydantic.models.voice_chat import *
from telegram_pydantic.models.inline_mode import *
from telegram_pydantic.models.input_media import *
from telegram_pydantic.models.callback_query import CallbackQuery
from telegram_pydantic.models.message_entity import MessageEntity
from telegram_pydantic.models.message_update import MessageUpdate
from telegram_pydantic.models.user_profile_photos import UserProfilePhotos
from telegram_pydantic.models.proximity_alert_triggered import ProximityAlertTriggered
from telegram_pydantic.models.message_auto_delete_timer_changed import MessageAutoDeleteTimerChanged



"""Defines the setup fro creating pip package."""

import io
import os

from setuptools import setup, find_packages

__version__ = "0.1.0"
NAME = "pydantic-telegram"
AUTHOR = "Daniel Miller"
AUTHOR_EMAIL = "danielmiller20@gmail.com"
DESCRIPTION = "Pydantic classes creating telegram bots."
LICENSE = "MIT"

here = os.path.abspath(os.path.dirname(__file__))

try:
    with io.open(os.path.join(here, "README.md"), encoding="utf8") as f:
        LONG_DESCRIPTION = "\n" + f.read()
except FileNotFoundError:
    LONG_DESCRIPTION = DESCRIPTION

setup(
    name=NAME,
    version=__version__,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    license=LICENSE,
    packages=find_packages(exclude=["test", "docs", "contrib"]),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',
    install_requires=[
        "pydantic>=1.8.2",
    ],

)



from typing import Any, Optional

from telegram_pydantic.models.input_media.input_media import InputMedia


class InputMediaDocument(InputMedia):
    thumb: Optional[Any]
    disable_content_type_detection: Optional[bool]



from pydantic import BaseModel


class User(BaseModel):
    id: int
    is_bot: bool
    first_name: str
    last_name: str = None
    username: str = None
    language_code: str = None
    can_join_groups: bool = None
    can_read_all_group_message: bool = None
    support_inline_queries: bool = None



from telegram_pydantic.models.poll.poll import Poll
from telegram_pydantic.models.poll.poll_answer import PollAnswer
from telegram_pydantic.models.poll.poll_option import PollOption

__all__ = ["Poll", "PollOption", "PollAnswer"]



from telegram_pydantic.models.chat.chat import Chat
from telegram_pydantic.models.chat.chat_photo import ChatPhoto
from telegram_pydantic.models.chat.chat_member import ChatMember
from telegram_pydantic.models.chat.chat_location import ChatLocation
from telegram_pydantic.models.chat.chat_invite_link import ChatInviteLink
from telegram_pydantic.models.chat.chat_permissions import ChatPermissions
from telegram_pydantic.models.chat.chat_member_updated import ChatMemberUpdated

__all__ = ["Chat", "ChatPhoto", "ChatMember", "ChatLocation", "ChatInviteLink", "ChatPermissions", "ChatMemberUpdated"]



from pydantic import BaseModel
from telegram_pydantic.models.user import User


class ChatMember(BaseModel):
    user: User
    status: str
    custom_title: str = None
    is_anonymous: bool = None
    can_be_edited: bool = None
    can_manage_chat: bool = None
    can_post_messages: bool = None
    can_edit_messages: bool = None
    can_delete_messages: bool = None
    can_manage_voice_chats: bool = None
    can_restrict_members: bool = None
    can_promote_members: bool = None
    can_change_info: bool = None
    can_invite_users: bool = None
    can_pin_messages: bool = None
    is_member: bool = None
    can_send_messages: bool = None
    can_send_media_messages: bool = None
    can_send_polls: bool = None
    can_send_other_messages: bool = None
    can_add_web_page_previews: bool = None
    until_date: int = None



from typing import Any

from pydantic import BaseModel
from telegram_pydantic.models.chat.chat_photo import ChatPhoto
from telegram_pydantic.models.chat.chat_location import ChatLocation
from telegram_pydantic.models.chat.chat_permissions import ChatPermissions


class Chat(BaseModel):
    id: int
    type: str
    title: str = None
    username: str = None
    first_name: str = None
    last_name: str = None
    photo: ChatPhoto = None
    bio: str = None
    description: str = None
    invite_link: str = None
    pinned_message: Any = None
    permissions: ChatPermissions = None
    slow_mode_delay: int = None
    message_auto_delete_time: int = None
    sticker_set_name: str = None
    can_set_sticker_set: bool = None
    linked_chat_id: int = None
    location: ChatLocation = None
